@@ -11,8 +11,7 @@ def strip_quotes(s):
     return s.strip('\'"')
 
 def getStdout(cmd_and_args):
-    # Can't use subprocess.check_output as it's not available in Python 2.6;
-    # It's also not quite the same as check_output, since we also verify that
+    # Can't use subprocess.check_output, since we also verify that
     # no stderr was produced
     p = subprocess.Popen([strip_quotes(cmd_and_args[0])] + cmd_and_args[1:],
                          stdout=subprocess.PIPE,
@@ -23,7 +22,7 @@ def getStdout(cmd_and_args):
         raise Exception("Command failed: " + str(cmd_and_args))
     if stderr:
         raise Exception("stderr from command: %s\nOutput:\n%s\n" % (cmd_and_args, stderr))
-    return stdout
+    return stdout.decode('utf-8')
 
 def mkdirp(path):
     try:
