@@ -1,4 +1,4 @@
-module Foo where
+module Mod where
 import A
 h :: Int
 h = g
