@@ -1,6 +1,6 @@
 {-# LANGUAGE DataKinds, TypeOperators, TypeFamilies #-}
 module Main(main) where
-import GHC.TypeLits
+import GHC.TypeLits as L
 import Data.Proxy
 
 --------------------------------------------------------------------------------
@@ -12,10 +12,10 @@ tsub _ _ = Proxy
 tsub2 :: Proxy (x + y) -> (Proxy x, Proxy y)
 tsub2 _ = (Proxy, Proxy)
 
-tdiv :: Proxy (x * y) -> Proxy y -> Proxy x
+tdiv :: Proxy (x L.* y) -> Proxy y -> Proxy x
 tdiv _ _ = Proxy
 
-tdiv2 :: Proxy (x * y) -> (Proxy x, Proxy y)
+tdiv2 :: Proxy (x L.* y) -> (Proxy x, Proxy y)
 tdiv2 _ = (Proxy, Proxy)
 
 troot :: Proxy (x ^ y) -> Proxy y -> Proxy x
